package com.hungraim.ltc.controller;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.dto.QueryDto;
import com.hungraim.ltc.pojo.entity.SysConfig.ChFndAttach;
import com.hungraim.ltc.pojo.entity.assessment.ChAprReport;
import com.hungraim.ltc.pojo.entity.assessment.ChAprTask;
import com.hungraim.ltc.pojo.entity.assessment.ChRefuseReason;
import com.hungraim.ltc.pojo.entity.disable.ChCfgSrvDisableLevel;
import com.hungraim.ltc.pojo.vo.ReportUpdateVO;
import com.hungraim.ltc.pojo.vo.assessment.*;
import com.hungraim.ltc.service.TaskService;
import com.hungraim.ltc.service.TppesApiException;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 失能评定Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/api.assessment/task")
@Slf4j
public class TaskController {

    @Autowired
    private TaskService taskService;

    /**
     * 评定任务分配、查询列表
     *
     * @param organId       适用机构代码
     * @param provincial    所在省
     * @param city          所在市
     * @param area          所在区域
     * @param street        所在街道
     * @param realName      失能人员姓名
     * @param certiCode     失能人员身份证号码
     * @param taskName      评定人员姓名
     * @param taskTel       评定人员手机号码
     * @param daysRemaining 评定剩余天数
     * @param status        任务状态
     * @param isReturn      是否退回
     * @param pageNum       当前页
     * @param pageSize      每页几条数据
     */
    @RequestMapping("/taskDistributionList")
    public Result<Page<TaskDistributionVO>> taskDistributionList(@RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize,
                                                                 String organId, String provincial, String city,
                                                                 String street, String realName, String certiCode, String taskName, String taskTel,
                                                                 String daysRemaining, String taskStatus, String isReturn, String area) {
        Page<TaskDistributionVO> page = new Page<>(pageNum, pageSize);
        page = taskService.taskDistributionList(page, organId, provincial, city, street, realName, certiCode, taskName, taskTel, daysRemaining, taskStatus, isReturn, area);
        return Result.success(page);
    }

    /**
     * 评定报告录入列表
     *
     * @param name      失能人员姓名
     * @param certiCode 失能人员身份证号码
     * @param tel       失能人员手机号码
     */
    @RequestMapping("/taskReportList")
    public Result<List<TaskReportVO>> taskReportList(String name, String certiCode, String tel) {
        List<TaskReportVO> taskReportList = taskService.taskReportList(name, certiCode, tel);
        return Result.success(taskReportList);
    }

    /**
     * 查询评定报告附件列表
     *
     * @param reportId 评定报告id
     */
    @RequestMapping("/reportFileList")
    public Result<List<ChFndAttach>> reportFileList(Long reportId) {
        Result<List<ChFndAttach>> listResult = taskService.reportFileList(reportId);
        if (!listResult.getCode().equals(ResultCode.SUCCESS.getCode())) {
            return Result.failed("请求获取附件列表错误：错误码{" + listResult.getCode() + "},错误信息:{" + listResult.getMsg() + "}");
        }
        return listResult;
    }

    /**
     * 通过报告id查询评定报告人员信息
     *
     * @param reportId 评定报告id
     */
    @RequestMapping("/personInfoList")
    public Result<List<PersonInfoVO>> personInfoList(String reportId) {
        List<PersonInfoVO> list = taskService.personInfoList(reportId);
        return Result.success(list);
    }

    /**
     * 查询评定人员列表
     *
     * @param provincial  失能人员所在省
     * @param city        失能人员所在市
     * @param area        失能人员所在区
     * @param organName   评定机构名称
     * @param name        评定人员姓名
     * @param tel         评定人员手机号码
     * @param groupLeader 是否组长0组长，1非组长
     */
    @RequestMapping("/aprEmpList")
    public Result<List<AprEmpVO>> aprEmpList(String provincial, String city, String area, String organName, String name, String tel, String groupLeader) {
        List<AprEmpVO> aprEmpS = taskService.aprEmpList(provincial, city, area, organName, name, tel, groupLeader);
        return Result.success(aprEmpS);
    }

    /**
     * 查询失能等级列表
     */
    @RequestMapping("/cfgSrvDisableLevelList")
    public Result<List<ChCfgSrvDisableLevel>> cfgSrvDisableLevelList() {
        List<ChCfgSrvDisableLevel> list = taskService.cfgSrvDisableLevelList();
        return Result.success(list);
    }

    /**
     * 评定报告新增
     * @param reportDetailVo
     //* @param taskId         评定任务id
     //* @param person1        鉴定人员1id
     //* @param person2        鉴定人员2id
     //* @param person3        鉴定人员3id
     //* @param evaluateTime   评估时间 格式:2020-11-12
     //* @param disableLevelId 失能等级id
     //* @param polNo          保单号
     //* @param remark         备注
     //* @param fileDataList   附件
     */
    @RequestMapping("/addReport")
    public Result addReport(ReportDetailVO reportDetailVo) {
        Integer person1 = reportDetailVo.getPerson1();
        Integer person2 = reportDetailVo.getPerson2();
        Integer person3 = reportDetailVo.getPerson3();
        Integer taskId = reportDetailVo.getTaskId();
        Integer disableLevelId = reportDetailVo.getDisableLevelId();
        String evaluateTime = reportDetailVo.getEvaluateTime();
        String polNo = reportDetailVo.getPolNo();
        String remark = reportDetailVo.getRemark();
        List<ChFndAttach> fileDataList = reportDetailVo.getFileDataList();
        if (person1 == null) {
            return Result.failed("鉴定人员1不能为空!");
        }
        if (taskId == null) {
            return Result.failed("评定任务id不能为空!");
        }
        if (disableLevelId == null) {
            return Result.failed("失能等级id不能为空!");
        }
        if (StringUtils.isBlank(evaluateTime)) {
            return Result.failed("评估时间不能为空!");
        }
        Date evaluateDate;
        try {
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
            evaluateDate = sdf.parse(evaluateTime);
        } catch (ParseException e) {
            return Result.failed("评估时间格式不正确!");
        }
        Result<Object> objectResult = taskService.addReport(taskId, person1, person2, person3, evaluateDate, disableLevelId, polNo, remark, fileDataList);
        if (!ResultCode.SUCCESS.getCode().equals(objectResult.getCode())) {
            //失败
            return Result.failed(objectResult.getMsg());
        }
        return Result.success();
    }

    /**
     * 评定报告修改
     *
     * @param reportId       评定报告id
     * @param person1        鉴定人员1id
     * @param person2        鉴定人员2id
     * @param person3        鉴定人员3id
     * @param evaluateTime   评估时间 格式:2020-11-12
     * @param disableLevelId 失能等级id
     * @param polNo          保单号
     * @param remark         备注
     * @param remark         备注
     * @param fileDataList   附件
     */
    @RequestMapping("/updateReport")
    public Result updateReport(ReportUpdateVO vo) {
        if (vo.getDisableLevelId() == null) {
            return Result.failed("失能等级不能为空!");
        }
        if (vo.getPolNo() == null) {
            vo.setPolNo("");
        }
        if (vo.getRemark() == null) {
            vo.setRemark("");
        }
        Date evaluateDate;
        try {
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
            evaluateDate = sdf.parse(vo.getEvaluateTime());
        } catch (ParseException e) {
            return Result.failed("评估时间格式不正确!");
        }
        taskService.updateReport(vo.getReportId(), vo.getPerson1(), vo.getPerson2(), vo.getPerson3(), evaluateDate, vo.getDisableLevelId(), vo.getPolNo(), vo.getRemark(), vo.getFileDataList());
        return Result.success();
    }

    /**
     * 评定任务分配
     *
     * @param taskId 评定任务id,如果多条以逗号(,)分隔
     * @param empId  评定人员id
     */
    @RequestMapping("/allotTask")
    public Result allotTask(String taskId, String empId) {
        if (StringUtils.isBlank(taskId) && StringUtils.isBlank(empId)) {
            return Result.failed("id不能为空!");
        }
        Result<Object> objectResult = taskService.allotTask(taskId, empId);
        if (!ResultCode.SUCCESS.getCode().equals(objectResult.getCode())) {
            //失败
            return Result.failed(objectResult.getMsg());
        }
        return Result.success();
    }

    /**
     * 分配历史信息列表
     */
    @RequestMapping("/allotTaskHisList")
    public Result<List<AllotTaskHisVO>> allotTaskHisList(Integer taskId) {
        List<AllotTaskHisVO> list = taskService.allotTaskHisList(taskId);
        return Result.success(list);
    }

    /**
     * 评定任务分组管理列表
     *
     * @param name      评定人员姓名
     * @param certiCode 评定人员身份证号码
     * @param tel       评定人员手机号码
     */
    @RequestMapping("/taskGroupList")
    public Result<List<TaskGroupVO>> taskGroupList(String name, String certiCode, String tel) {
        List<TaskGroupVO> taskReportList = taskService.taskGroupList(name, certiCode, tel);
        return Result.success(taskReportList);
    }

    /**
     * 评定任务分组管理列表详情
     *
     * @param groupNumber 组号
     */
    @RequestMapping("/taskGroupInfoList")
    public Result<List<TaskGroupInfoVO>> taskGroupInfoList(String groupNumber) {
        if (StringUtils.isBlank(groupNumber)) {
            return Result.failed("组号不能为空!");
        }
        List<TaskGroupInfoVO> groupInfoList = taskService.taskGroupInfoList(groupNumber);
        return Result.success(groupInfoList);
    }

    /**
     * 评定任务分组管理列表详情详情
     *
     * @param pushId 任务组id
     */
    @RequestMapping("/taskGroupInfoListInfo")
    public Result<TaskGroupInfoListInfoVO> taskGroupInfoListInfo(String pushId) {
        if (StringUtils.isBlank(pushId)) {
            return Result.failed("任务组id不能为空!");
        }
        TaskGroupInfoListInfoVO taskGroupInfoListInfoVO = taskService.taskGroupInfoListInfo(pushId);
        return Result.success(taskGroupInfoListInfoVO);
    }

    /**
     * 评定任务分组管理(整组操作)
     *
     * @param groupNumber  组号
     * @param status       分组状态 未分配(拒绝(重新分配)):0;已分配:1;已接受:2;已完成:3;拒绝（中止）:4,拒绝（终止）:5
     * @param refuseReason 拒绝原因id
     * @param refuseRemark 拒绝备注
     */
    @RequestMapping("/taskGroupByGroup")
    public Result taskGroupByGroup(String groupNumber, Integer status, Short refuseReason, String refuseRemark) {
        if (StringUtils.isBlank(groupNumber)) {
            return Result.failed("组号不能为空!");
        }
        if (status == null || status < 0 || status > 5) {
            return Result.failed("状态异常!");
        }
        if (status == 4 || status == 5) {
            if (refuseReason == null) {
                return Result.failed("拒绝原因不能为空!");
            }
        }
        Result<Object> objectResult = taskService.taskGroupByGroup(groupNumber, status, refuseReason, refuseRemark);
        if (!ResultCode.SUCCESS.getCode().equals(objectResult.getCode())) {
            //失败
            return Result.failed(objectResult.getMsg());
        }
        return Result.success();
    }

    /**
     * 评定任务分组管理
     *
     * @param pushId       任务组id
     * @param status       分组状态 未分配(拒绝(重新分配)):0;已分配:1;已接受:2;已完成:3;拒绝（中止）:4,拒绝（终止）:5
     * @param refuseReason 拒绝原因id
     * @param refuseRemark 拒绝备注
     */
    @RequestMapping("/taskGroup")
    public Result taskGroup(Integer pushId, Integer status, Short refuseReason, String refuseRemark) {
        if (status == null || status < 0 || status > 5) {
            return Result.failed("状态异常!");
        }
        if (pushId == null) {
            return Result.failed("任务组id不能为空!");
        }
        if (status == 4 || status == 5) {
            if (refuseReason == null) {
                return Result.failed("拒绝原因不能为空!");
            }
        }
        Result<Object> objectResult = taskService.taskGroup(pushId, status, refuseReason, refuseRemark);
        if (!ResultCode.SUCCESS.getCode().equals(objectResult.getCode())) {
            //失败
            return Result.failed(objectResult.getMsg());
        }
        return Result.success();
    }

    /**
     * 查询拒绝原因
     *
     * @return 拒绝原因
     */
    @RequestMapping("/refuseReasonList")
    public Result<List<ChRefuseReason>> refuseReasonList() {
        List<ChRefuseReason> refuseReasons = taskService.refuseReasonList();
        return Result.success(refuseReasons);
    }

    /**
     * 设置预约日期和备注
     *
     * @param pushId 分组id
     * @param time   预约日期 yyyy-MM-dd
     * @param remark 备注
     */
    @RequestMapping("/updatePushTimeAndRemark")
    public Result updatePushTimeAndRemark(String pushId, String time, String remark) {
        if (StringUtils.isBlank(pushId)) {
            return Result.failed("分组id不能为空!");
        }
        if (StringUtils.isBlank(time)) {
            return Result.failed("预约日期不能为空!");
        }
        if (StringUtils.isBlank(remark)) {
            return Result.failed("备注不能为空!");
        }
        Date timeDate;
        try {
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
            timeDate = sdf.parse(time);
        } catch (ParseException e) {
            return Result.failed("预约日期格式不正确!");
        }
        Result<Object> objectResult = taskService.updatePushTimeAndRemark(pushId, timeDate, remark);
        if (!ResultCode.SUCCESS.getCode().equals(objectResult.getCode())) {
            //失败
            return Result.failed(objectResult.getMsg());
        }
        return Result.success();
    }

    /**
     * 查询鉴定任务组信息
     * @return
     * @author wqs
     */
    @ResponseBody
    @RequestMapping(value= "/chIpad/queryAppraisalInfo", method = RequestMethod.POST)
    public String queryAppraisalInfo(@RequestBody QueryDto queryDto) throws TppesApiException {  //pad端优化 增加任务预约日期1 任务预约日期2

        List<TaskGroupInfoVO> resultMap= taskService.queryAppraisalInfo(queryDto.getAprEmpId(),queryDto.getAppointStartTime(),queryDto.getAppointEndTime(),queryDto.getQueryBeginDate(),queryDto.getQueryEndDate(),queryDto.getGroupNum(),queryDto.getPageNo(),queryDto.getPageSize());  //pad端增加两个字段

        String json= JSON.toJSONString(resultMap);

        return json;
    }

    /**
     * 查询鉴定任务组信息
     * @return
     * @author wqs
     */
    @ResponseBody
    @RequestMapping(value= "/chIpad/queryAppraisalInfoByPage")
    public String queryAppraisalInfoByPage(@RequestBody QueryDto queryDto) throws TppesApiException {  //pad端优化 增加任务预约日期1 任务预约日期2

        Page<TaskGroupInfoByPageVO> resultMap= taskService.queryAppraisalInfoByPage(queryDto.getAprEmpId(),queryDto.getAppointStartTime(),queryDto.getAppointEndTime(),queryDto.getQueryBeginDate(),queryDto.getQueryEndDate(),queryDto.getGroupNum(),queryDto.getPageNo(),queryDto.getPageSize());   //pad端增加两个字段

        String json= JSON.toJSONString(resultMap);

        return json;
    }

    /**
     * 鉴定人员鉴定任务详情获取
     * @return
     * @author wqs
     */
    @RequestMapping(value= "/chIpad/taskDetailInfo")
    public IPage<ChAprTask> taskDetailInfo(@RequestBody QueryDto queryDto) throws TppesApiException {  //pad端优化 增加两个字段 是为了传到详情页面展示

        List<Map<String,Object>> resultList=new ArrayList<Map<String, Object>>();
        if(queryDto.getPageNo()==null || "".equals(queryDto.getPageNo())){
            queryDto.setPageNo(1);
        }
        IPage<ChAprTask> resultMap= taskService.apprTaskDetailInfo(queryDto.getAppointStartTime(),queryDto.getAppointEndTime(), queryDto.getStatus(),queryDto.getTaskGroupNo(), queryDto.getPageNo(),queryDto.getPageSize());  //pad端优化 增加三个字段 任务预约日期1 任务预约日期2  状态
        return resultMap;
    }


    /**
     * 单条任务拒绝
     * @return
     * @author wqs
     */
    @ResponseBody
    @RequestMapping(value= "/chIpad/taskRefuseCause")
    public Result taskRefuseCause(@RequestBody QueryDto queryDto)
            throws com.hungraim.ltc.service.TppesApiException {
        String json="";
        String optType="1";//操作类型	0-鉴定机构管理人员操作，1-鉴定人员操作；
        //List<Map<String,Object>> aprList= (List<Map<String, Object>>) request.getSession().getAttribute("aprList");//鉴定机构
       // String aprEmpId=String.valueOf(aprList.get(0).get("empId"));//操作人id
        //String aprOrganId=String.valueOf(aprList.get(0).get("organId"));       //操作机构id
        SimpleDateFormat sdf=new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String optTime=sdf.format(new Date());//操作时间YYYY-MM-DD HH24:MM:SS
        //logger.info("调用ipadSurveyReportService.taskRefuseCause接口传入参数："+taskId+" "+optType+" "
        //        + aprOrganId+" "+ aprEmpId+" "+ optTime+" "+ refuseReason+" " + refuseRemark+" " + status + " " + taskGroupNo);

        Result<Object> objectResult= taskService.taskRefuseCause( queryDto.getTaskId(), optType, queryDto.getOrganId(), queryDto.getEmpId(), optTime, queryDto.getRefuseReason(), queryDto.getRefuseRemark(), queryDto.getStatus(), queryDto.getTaskGroupNo(), queryDto.getTaskPushId());

    if (!ResultCode.SUCCESS.getCode().equals(objectResult.getCode())) {
            //失败
            return Result.failed(objectResult.getMsg());
        }
        return Result.success();
    }

    /**
     * 开始鉴定任务
     * @return
     * @author wqs
     */
    @ResponseBody
    @RequestMapping(value= "/chIpad/startApprTask")
    public Result startApprTask(@RequestBody QueryDto queryDto)
            throws com.hungraim.ltc.service.TppesApiException {
        Map<String,Object> resultMap =new HashMap<String, Object>();
        String json="";
        //List<Map<String,Object>> aprList= (List<Map<String, Object>>) request.getSession().getAttribute("aprList");//鉴定机构
        //logger.info("开始评定aprList: " + aprList);
        String operationId=queryDto.getEmpId();//操作人id
        String operationOrganId=queryDto.getOrganId();       //操作机构id
        //logger.info("调用ipadSurveyReportService.taskRefuseCause接口传入参数："+taskId+" "+operationId+" " + operationOrganId+" "+ taskGroupNo);
        Result<Object> objectResult= taskService.startApprTask( queryDto.getTaskId(), operationId, operationOrganId, queryDto.getTaskGroupNo());

        if (!ResultCode.SUCCESS.getCode().equals(objectResult.getCode())) {
            //失败
            return Result.failed(objectResult.getMsg());
        }
        return Result.success();
    }


    /**
     * 单条任务详情
     * @return
     * @author wqs
     */
    @ResponseBody
    @RequestMapping(value= "/chIpad/singleTaskDetails")
    public String singleTaskDetails(HttpServletRequest request,@RequestBody QueryDto queryDto)
            throws com.hungraim.ltc.service.TppesApiException {
        Map<String,Object> resultMap =new HashMap<String, Object>();
        ChAprTask chAprTask = new ChAprTask();
        String json="";
        String chPadCityFlag= (String) request.getSession().getAttribute("chPadCityFlag");
        if(null!=chPadCityFlag && "320200".equals(chPadCityFlag)){
            //无锡用户调用无锡单条任务详情接口
            //logger.info("调用ipadSurveyReportService.singleTaskDetailsWuXi接口传入参数："+taskId);
            chAprTask =taskService.singleTaskDetailsWuXi(queryDto.getTaskId(),queryDto.getTaskGroupNo(),queryDto.getTaskPushId());
        }else{
            //logger.info("调用ipadSurveyReportService.singleTaskDetails接口传入参数："+taskId);
            chAprTask= taskService.singleTaskDetails(queryDto.getTaskId(),queryDto.getTaskGroupNo(),queryDto.getTaskPushId());
        }

        json= com.alibaba.fastjson.JSON.toJSONString(chAprTask);
        //logger.info("resultMap"+resultMap);
        return json;
    }

    /**
     * 报告查看 获取鉴定报告详情
     * @return
     * @author wqs
     */
    @RequestMapping(value= "/chIpad/taskReportDetails")
    public ChAprReport taskReportDetails(HttpServletRequest request, @RequestBody QueryDto queryDto)throws com.hungraim.ltc.service.TppesApiException {
        Map<String,Object> resultMap =new HashMap<String, Object>();
        String disabInfoId=request.getParameter("disabInfoId");
        String chPadCityFlag= (String) request.getSession().getAttribute("chPadCityFlag");
        ChAprReport chAprReport = taskService.taskReportDetails(queryDto.getTaskId());
        return  chAprReport;

        /*if("01".equals(flag)){
            //失能人员、鉴定人员信息展示页面
            return new ModelAndView("disApprInfo");
        }else if("02".equals(flag)){
            //评分结果展示
            return new ModelAndView("disApprScore");
        }else if("03".equals(flag)){
            //失能人员鉴定图片展示
            return new ModelAndView("disAttach");
        }else if("04".equals(flag)){
            //鉴定结果展示
            return new ModelAndView("disApprResult");
        }else{
            //没有值回到登录页面
            return new ModelAndView("ipadChLogin");
        }*/
    }

    @RequestMapping("/chIpad/findReportVideo")
    @ResponseBody
    public String findReportVideo(String taskId){
        List<Map<String,Object>> list = taskService.findReportVideo(taskId);
        String json = com.alibaba.fastjson.JSON.toJSONString(list);
        return json;
    }


    @RequestMapping("/chIpad/uploadVideo")
    @ResponseBody
    public Result uploadVideo(String taskId,String videoUrl,String videoName,HttpServletRequest req,String fileId){
        Map<String,Object> userMap = (Map<String, Object>) req.getSession().getAttribute("ipadChUserMap");
        String padUserName = (String) userMap.get("chName");
        int i=taskService.uploadVideo(taskId,videoUrl,videoName,padUserName,fileId);
        if(i>0){
            return Result.success();
        }else {
            return Result.failed();
        }

    }

    @RequestMapping("/chIpad/deleteVodFile")
    @ResponseBody
    public Result deleteVodFile(@RequestParam String fileId,@RequestParam String taskId){//文件ID和评定任务ID
        Result<Object> objectResult=taskService.deleteVodFile(fileId,taskId);
        if (!ResultCode.SUCCESS.getCode().equals(objectResult.getCode())) {
            //失败
            return Result.failed(objectResult.getMsg());
        }
        return Result.success();
    }

    /**
     * 合并项目相同的项
     * @param chPfList
     * @return
     */
    public List<List<Map<String,Object>>> changeList(List<Map<String,Object>> chPfList) {
        List<List<Map<String, Object>>> resultList = new ArrayList<List<Map<String, Object>>>();
        if (chPfList != null && chPfList.size() > 0) {
            List<String> itemList = new ArrayList<String>();
            for (int i = 0; i < chPfList.size(); i++) {
                String itemName = String.valueOf(chPfList.get(i).get("itemName"));
                if (itemList.size() == 0) {
                    itemList.add(itemName);
                    List<Map<String, Object>> chList = new ArrayList<Map<String, Object>>();
                    chList.add(chPfList.get(i));
                    resultList.add(chList);
                } else {
                    String isExist = "N";
                    tips1:
                    for (int j = 0; j < itemList.size(); j++) {
                        String itemName2 = itemList.get(j);
                        if (itemName.equals(itemName2)) {
                            isExist = "Y";
                            List<Map<String, Object>> chList = resultList.get(j);
                            if (chList != null) {
                                chList.add(chPfList.get(i));
                                resultList.set(j, chList);
                            }
                            break tips1;
                        }
                    }
                    if ("N".equals(isExist)) {
                        itemList.add(itemName);
                        List<Map<String, Object>> chList = new ArrayList<Map<String, Object>>();
                        chList.add(chPfList.get(i));
                        resultList.add(chList);
                    }
                }
            }
        }
        return resultList;
    }
}
