package com.hungraim.ltc.governance.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.governance.service.SrvTaskService;
import com.hungraim.ltc.pojo.vo.governance.*;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.format.annotation.DateTimeFormat;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.Date;
import java.util.List;

/**
 * 服务计划Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/api.governance/srvTask")
@Slf4j
public class SrvTaskController {

    @Autowired
    private SrvTaskService srvTaskService;

    /**
     * 查询护理机构人员列表
     *
     * @param pageNum    页码
     * @param pageSize   每页大小
     * @param srvOrganId 护理服务机构id
     * @param empName    护理人员姓名
     * @param certifType  护理人员证件类型
     * @param certifNum  护理人员证件号码
     */
    @RequestMapping("/getSrvOrganEmpList")
    public Result<Page<OrganEmpVO>> getSrvOrganEmpList(@RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize,
                                                       String srvOrganId, String empName, String certifType, String certifNum) {
        if (StringUtils.isBlank(srvOrganId)) {
            return Result.failed("参数异常!");
        }
        Page<OrganEmpVO> page = new Page<>(pageNum, pageSize);
        page = srvTaskService.getSrvOrganEmpList(page, srvOrganId, empName, certifType, certifNum);
        return Result.success(page);
    }

    /**
     * 服务计划制定列表
     *
     * @param srvOrganId  护理服务机构id
     * @param disableName 失能人员姓名
     * @param disableTel  失能人员手机号码
     * @param taskStatus  服务计划状态
     */
    @RequestMapping("/getSrvTaskList")
    public Result<Page<SrvTaskVO>> getSrvTaskList(@RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize,
                                                  Long srvOrganId, String disableName, String disableTel, String taskStatus) {
        Page<SrvTaskVO> page = new Page<>(pageNum, pageSize);
        page = srvTaskService.getSrvTaskList(page, srvOrganId, disableName, disableTel, taskStatus);
        return Result.success(page);
    }

    /**
     * 服务计划查询列表
     *
     * @param srvOrganId  护理机构id
     * @param disableName 失能人员姓名
     * @param disableTel  失能人员手机号码
     * @param empName     护理人员姓名
     * @param certifNum   护理人员证件号码
     * @param startTime   服务计划开始时间
     * @param endTime     服务计划结束时间
     * @param status      任务状态
     * @param modeId      服务方式
     */
    @RequestMapping("/getSrvTaskDetailList")
    public Result<Page<SrvTaskDetailVO>> getSrvTaskDetailList(@RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize,
                                                              Integer srvOrganId, String disableName, String disableTel,
                                                              String empName, String certifNum, @DateTimeFormat(pattern = "yyyy-MM-dd") Date startTime, @DateTimeFormat(pattern = "yyyy-MM-dd") Date endTime,
                                                              String status, String modeId) {
        Page<SrvTaskDetailVO> page = new Page<>(pageNum, pageSize);
        page = srvTaskService.getSrvTaskDetailList(page, srvOrganId, disableName, disableTel, empName, certifNum, startTime, endTime, status, modeId);
        return Result.success(page);
    }

    /**
     * 查询服务计划制定详情及附件列表
     *
     * @param programId 服务方案id
     */
    @RequestMapping("/getSrvTaskInfo")
    public Result<SrvTaskInfoListVO> getSrvTaskInfoList(String programId) {
        if (StringUtils.isBlank(programId)) {
            return Result.failed("参数异常!");
        }
        List<SrvTaskInfoVO> taskInfos = srvTaskService.getSrvTaskInfoList(programId);
        SrvTaskInfoListVO taskInfoListVO = new SrvTaskInfoListVO();
        if (taskInfos != null && taskInfos.size() > 0) {
            taskInfoListVO.setProgramId(taskInfos.get(0).getProgramId());
            taskInfoListVO.setDisabInfoId(taskInfos.get(0).getDisabInfoId());
            taskInfoListVO.setTaskList(taskInfos);
        }
        return Result.success(taskInfoListVO);
    }

    /**
     * 新增或者修改服务计划
     */
    @PostMapping("/addOrUpdateSrvTask")
    public Result<List<SrvTaskInfoVO>> addSrvTask(SrvTaskInfoListVO param) {
        String programId = param.getProgramId();
        List<SrvTaskInfoVO> taskList = param.getTaskList();
        if (StringUtils.isBlank(programId) || taskList == null || taskList.size() <= 0) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        try {
            for (int i = 0; i < taskList.size(); i++) {
                SrvTaskInfoVO srvTaskInfoVO = taskList.get(i);
                if (srvTaskInfoVO.getSrvEmpId() == null) {
                    return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
                }
                if (srvTaskInfoVO.getTaskDetails() == null || srvTaskInfoVO.getTaskDetails().size() <= 0) {
                    return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
                }
            }
            srvTaskService.addOrUpdateSrvTask(param);
        } catch (RuntimeException e) {
            e.printStackTrace();
            return Result.failed(e.getMessage());
        }
        return Result.success();
    }

}
