package com.hungraim.ltc.governance.controller;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.governance.service.SuperviseOrganEmpService;
import com.hungraim.ltc.pojo.entity.serviceManage.ChSuperviseOrgan;
import com.hungraim.ltc.pojo.entity.serviceManage.ChSuperviseOrganEmp;
import com.hungraim.ltc.pojo.vo.governance.ChSuperviseOrganEmpVo;
import com.hungraim.ltc.pojo.vo.governance.SuperviseOrganEmpVO;
import com.hungraim.ltc.pojo.vo.governance.SuperviseOrganVO;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 监管机构及监管机构人员信息管理Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/api.governance/supervise")
@Slf4j
public class SuperviseOrganEmpController {

    @Autowired
    private SuperviseOrganEmpService superviseOrganEmpService;

    /**
     * 根据organId获取对应的监管机构列表
     *
     * @param organId 适用机构id
     * @return 返回监管机构列表
     */
    @GetMapping("/spvOrganListByOrganId")
    public Result<List<ChSuperviseOrgan>> getSpvOrganListByOrganId(String organId) {
        if (StrUtil.isBlank(organId)) {
            return Result.success();
        }
        List<ChSuperviseOrgan> list = superviseOrganEmpService.list(new LambdaQueryWrapper<ChSuperviseOrgan>().eq(ChSuperviseOrgan::getOrganId, organId));
        return Result.success(list);
    }

    /**
     * 监管机构人员信息列表
     *
     * @param pageNum     页码
     * @param pageSize    每页展示条数
     * @param organId     适用机构id
     * @param isIncluded  是否包含下级机构,值为true，则包含organId的下层机构
     * @param organName   监管机构名称
     * @param spvEmpType  监管人员类型 监管人员：0；管理人员：1
     * @param spvEmpName  监管人员姓名
     * @param mobilePhone 监管人员手机号
     * @param isLock      状态 有效：0；失效：1
     */
    @RequestMapping("/superviseOrganEmpList")
    public Result<Page<SuperviseOrganEmpVO>> superviseOrganEmpList(@RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize,
                                                                   Long organId, Boolean isInvolveChild, String organName, String spvEmpType, String spvEmpName, String mobilePhone, String isLock) {
        Page<SuperviseOrganEmpVO> page = new Page<>(pageNum, pageSize);
        page = superviseOrganEmpService.superviseOrganEmpList(page, organId, isInvolveChild, organName, spvEmpType, spvEmpName, mobilePhone, isLock);
        return Result.success(page);
    }

    /**
     * 获取监管人员详情
     *
     * @param spvEmpId 监管人员id
     * @return 返回监管人员详情
     */
    @GetMapping("/superviseOrganEmp")
    public Result<ChSuperviseOrganEmpVo> getSuperviseOrganEmp(Long spvEmpId) {
        if (null == spvEmpId) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        ChSuperviseOrganEmpVo chSuperviseOrganEmp = superviseOrganEmpService.getSuperviseOrganEmp(spvEmpId);
        return Result.success(chSuperviseOrganEmp);
    }

    /**
     * 更改监管机构人员状态
     *
     * @param spvEmpId 监管机构人员id
     * @param isLock   状态 有效：0；失效：1
     */
    @DeleteMapping("/updateEmpStatus")
    public Result updateEmpStatus(String spvEmpId, Short isLock) {
        if (StringUtils.isBlank(spvEmpId) || isLock == null || (isLock != 1 && isLock != 0)) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        superviseOrganEmpService.updateEmpStatus(spvEmpId, isLock);
        return Result.success();
    }

    /**
     * 新增或编辑监管机构人员
     *
     * @param chSuperviseOrganEmp 监管机构人员实体对象
     */
    @PostMapping("/insertOrUpdateEmpInfo")
    public Result insertOrUpdateEmpInfo(ChSuperviseOrganEmp chSuperviseOrganEmp) {
        //参数校验
        if (chSuperviseOrganEmp.getSpvOrganId() == null) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        if (StringUtils.isBlank(chSuperviseOrganEmp.getSpvEmpName()) || StringUtils.isBlank(chSuperviseOrganEmp.getCertifType()) || StringUtils.isBlank(chSuperviseOrganEmp.getGender()) || StringUtils.isBlank(chSuperviseOrganEmp.getMobilePhone())) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        superviseOrganEmpService.insertOrUpdateEmpInfo(chSuperviseOrganEmp);
        return Result.success();
    }

    /**
     * 监管机构信息列表
     *
     * @param pageNum      页码
     * @param pageSize     每页展示条数
     * @param organId      适用机构id
     * @param isIncluded   是否包含下级机构,值为true，则包含organId的下层机构
     * @param spvOrganName 监管机构名称
     */
    @RequestMapping("/superviseOrganList")
    public Result<Page<SuperviseOrganVO>> superviseOrganList(@RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize,
                                                             Long organId, Boolean isInvolveChild, String spvOrganName) {
        Page<SuperviseOrganVO> page = new Page<>(pageNum, pageSize);
        page = superviseOrganEmpService.superviseOrganList(page, organId, isInvolveChild, spvOrganName);
        return Result.success(page);
    }

    /**
     * 更改监管机构状态
     *
     * @param spvOrganId 监管机构id
     * @param isLock     状态 有效：0；失效：1
     */
    @DeleteMapping("/updateSpvStatus")
    public Result updateSpvStatus(String spvOrganId, Short isLock) {
        if (StringUtils.isBlank(spvOrganId) || isLock == null || (isLock != 1 && isLock != 0)) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        superviseOrganEmpService.updateSpvStatus(spvOrganId, isLock);
        return Result.success();
    }

    /**
     * 新增或编辑监管机构信息
     *
     * @param spvOrgan spvOrganId              监管机构id 没有就新增,有就编辑
     *                 organId                 适用机构id
     *                 districtProvince        所在省
     *                 districtCity            所在市
     *                 districtArea            所在区
     *                 spvOrganName            监管机构名称
     *                 unifiedSocialCreditCode 统一社会信用代码
     *                 contactName             机构联系人姓名
     *                 contactTel              联系人手机号
     *                 contactMail             机构联系人邮箱
     *                 accName                 银行账户名称
     *                 bankAccName             银行开户行名称
     *                 bankNo                  银行账号
     */
    @PostMapping("/insertOrUpdateSpvInfo")
    public Result insertOrUpdateSpvInfo(ChSuperviseOrgan spvOrgan) {
        //参数校验
        if (StringUtils.isBlank(spvOrgan.getOrganId())) {//适用机构id
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        if (StringUtils.isBlank(spvOrgan.getDistrictProvince()) || StringUtils.isBlank(spvOrgan.getDistrictCity()) || StringUtils.isBlank(spvOrgan.getDistrictArea())) {//所在省市区
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        if (StringUtils.isBlank(spvOrgan.getSpvOrganName())) {//监管机构名称
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        if (StringUtils.isBlank(spvOrgan.getContactName())) {//机构联系人姓名
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        if (StringUtils.isBlank(spvOrgan.getContactTel())) {//联系人手机号
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        superviseOrganEmpService.insertOrUpdateSpvInfo(spvOrgan);
        return Result.success();
    }

    /**
     * 获取监管机构相关信息
     *
     * @param spvOrganId 监管机构id
     * @return 返回相关信息
     */
    @GetMapping("/superviseOrgan")
    public Result<ChSuperviseOrgan> getSuperviseOrgan(Long spvOrganId) {
        if (null == spvOrganId) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        ChSuperviseOrgan superviseOrgan = superviseOrganEmpService.getSuperviseOrgan(spvOrganId);
        return Result.success(superviseOrgan);
    }
}
